==> haskell-connection-0.3.1-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 connection
version:              0.3.1
visibility:           public
id:                   connection-0.3.1-CTLvVACYtTC5OnVbsEOKrc
key:                  connection-0.3.1-CTLvVACYtTC5OnVbsEOKrc
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-connection
synopsis:             Simple and easy network connections API
description:
    Simple network library for all your connection need.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  fbc1f1766d198a7193a60ee0f388b99d
exposed:              True
exposed-modules:      Network.Connection
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-8.10.1/site-local/connection-0.3.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/connection-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/connection-0.3.1
hs-libraries:         HSconnection-0.3.1-CTLvVACYtTC5OnVbsEOKrc
depends:
    base-4.14.0.0 basement-0.0.11-9QYya5vCkyJDGzQl8Ea7rD
    bytestring-0.10.10.0 containers-0.6.2.1
    data-default-class-0.1.2.0-AZTcEqCsR4uCdCN1ROsSjZ
    network-3.1.2.0-17TAgcOYpYlAVBy4dzi75o
    socks-0.6.1-1wGsM0hUCZs90dcFByCjQy tls-1.5.4-2WysyqulXAY9p8eLiTuEEK
    x509-1.7.5-HmjI3qDq55mCHvmCXqmpjC
    x509-store-1.6.7-65ed34MXchIIqG4IuBSCAJ
    x509-system-1.6.6-LCcwK3gg6KdLIdc5yBDWBR
    x509-validation-1.6.11-LGEJqzMJt1PBLlaxe1yZlf

haddock-interfaces:   /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html:         /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-connection-0.3.1-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 connection
version:              0.3.1
visibility:           public
id:                   connection-0.3.1-48qEh5O7AiXF3yHKsQ1Bcs
key:                  connection-0.3.1-48qEh5O7AiXF3yHKsQ1Bcs
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-connection
synopsis:             Simple and easy network connections API
description:
    Simple network library for all your connection need.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  a8d9bf09877152d34216c4118674ffe4
exposed:              True
exposed-modules:      Network.Connection
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-8.10.2/site-local/connection-0.3.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/connection-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/connection-0.3.1
hs-libraries:         HSconnection-0.3.1-48qEh5O7AiXF3yHKsQ1Bcs
depends:
    base-4.14.1.0 basement-0.0.11-CejmV4k3OtGGKPkDYOlSof
    bytestring-0.10.10.0 containers-0.6.2.1
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    network-3.1.2.0-F7RvimuUXfr8J8mPq0Fg6c
    socks-0.6.1-JjEcF3nNnTuI6kFNaDmGfH tls-1.5.4-4B4XDkPBTLf6pqC6XA6E7J
    x509-1.7.5-CtMyQ2iQ5lL3UiK7Ynnps
    x509-store-1.6.7-AcxBLOXRooDFAD8quvqrFi
    x509-system-1.6.6-25WdolirnxBAqz9X8enbDT
    x509-validation-1.6.11-2tE7UwhRMzkFUbm9Rmldnq

haddock-interfaces:   /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html:         /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
